@@ -166,6 +166,8 @@ class options(ranaModule):
          ("never", "never", "display:blankingModeChanged")],
          "Display",
          "always")
+      if display.usesDashboard():
+        self.addBoolOption("Redraw when on dashboard", "redrawOnDashboard", 'Display', False)
 
 #    self.addOption("Network", "threadedDownload",
 ##      [("off","No use of network"),
@@ -294,12 +296,11 @@ class options(ranaModule):
        "Navigation",
        "en en") # TODO: use locale for default language ?
 
-    self.addOption("Autostart navigation", "autostartNavigationDefaultOn",
-      [('disabled',"Disabled"),
-       ('first',"From first point"),
-       ('closest',"From closest point")],
+    self.addOption("Autostart navigation", "autostartNavigationDefaultOnAutoselectTurn",
+      [('disabled',"OFF"),
+       ('enabled',"ON")],
        "Navigation",
-       'closest')
+       'enabled')
 
     self.addOption("Point reached distance", "pointReachedDistance",
       [(10,"10 m"),
@@ -335,6 +336,25 @@ class options(ranaModule):
        "POI",
        "dump")
 
+    # * themes *
+    icons = self.m.get('icons', None)
+    if icons:
+      defaultTheme = icons.defaultTheme
+      themeList = icons.getThemeList()
+      # check if current theme exists
+      currentTheme = self.get('currentTheme', None)
+      if currentTheme != None:
+        if currentTheme not in themeList:
+          self.set('currentTheme', defaultTheme) # theme not valid, reset to default
+
+      themeChangedMessage = "icons:themeChanged"
+      nameValueList = map(lambda x: (x,x,themeChangedMessage), themeList)
+      self.addOption("Current theme", "currentTheme",
+      nameValueList,
+       "Themes",
+       defaultTheme)
+
+
     # Add all our categories to the "options" menu
     self.menuModule = self.m.get("menu", None)
     if(self.menuModule):
